import 'package:bloc/bloc.dart';
import 'package:flutter/foundation.dart';

class AppBlocObserver extends BlocObserver {
  final bool printEvent;
  final bool printError;
  final bool printChange;
  final bool printTransition;

  AppBlocObserver({
    this.printEvent = true,
    this.printError = true,
    this.printTransition = true,
    this.printChange = true,
  });

  @override
  void onEvent(Bloc<dynamic, dynamic> bloc, Object? event) {
    super.onEvent(bloc, event);
    if (printEvent) {
      debugPrint(event.toString());
    }
  }

  @override
  void onError(BlocBase<dynamic> bloc, Object error, StackTrace stackTrace) {
    if (printError) {
      debugPrint(error.toString());
    }
    super.onError(bloc, error, stackTrace);
  }

  @override
  void onChange(BlocBase<dynamic> bloc, Change<dynamic> change) {
    super.onChange(bloc, change);
    if (printChange) {
      debugPrint(change.toString());
    }
  }

  @override
  void onTransition(
    Bloc<dynamic, dynamic> bloc,
    Transition<dynamic, dynamic> transition,
  ) {
    super.onTransition(bloc, transition);
    if (printTransition) {
      debugPrint(transition.toString());
    }
  }
}